.. _{{ fullname }}:


.. raw:: html

    <br>

.. title:: {{ fullname }}

.. raw:: html

    <center><b>

:ref:`home  <home>` - :ref:`manual <manual>` - :ref:`source <source>`

.. raw: html
    </b></center>
    <br><br>
    <center><b>

**{{ fullname }}**

.. raw:: html

    </b></center>

.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:

.. raw:: html

    <br><br>
'''
